# MIRO - DATAWORKBENCH

Personal project

Tools for data analysis
- databox
- ...

## RELEASES

### 0.1.3 2024-03-02 - Formalize events (allow grey box cache testing)

### 0.1.2 2024-03-01 - First Pypi release
